@@ -1,12 +1,10 @@
 package DateTime::Functions;
-
+$DateTime::Functions::VERSION = '0.13';
 use 5.006;
 use strict;
 use warnings;
 use parent 'Exporter';
 
-our $VERSION = '0.11';
-
 use DateTime ();
 
 our @EXPORT = qw(
@@ -21,11 +19,6 @@ our @EXPORT = qw(
 
 DateTime::Functions - Procedural interface to DateTime functions
 
-=head1 VERSION
-
-This document describes version 0.10 of DateTime::Functions, released
-December 9, 2010
-
 =head1 SYNOPSIS
 
     use DateTime::Functions;
